==> logs-1.101.0-sources.jar: software/amazon/awscdk/services/logs/RetentionDays.java <==
package software.amazon.awscdk.services.logs;

/**
 * How long, in days, the log contents will be retained.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:41.999Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.RetentionDays")
public enum RetentionDays {
    /**
     * 1 day.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    ONE_DAY,
    /**
     * 3 days.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    THREE_DAYS,
    /**
     * 5 days.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FIVE_DAYS,
    /**
     * 1 week.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    ONE_WEEK,
    /**
     * 2 weeks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TWO_WEEKS,
    /**
     * 1 month.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    ONE_MONTH,
    /**
     * 2 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TWO_MONTHS,
    /**
     * 3 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    THREE_MONTHS,
    /**
     * 4 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FOUR_MONTHS,
    /**
     * 5 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FIVE_MONTHS,
    /**
     * 6 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    SIX_MONTHS,
    /**
     * 1 year.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    ONE_YEAR,
    /**
     * 13 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    THIRTEEN_MONTHS,
    /**
     * 18 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    EIGHTEEN_MONTHS,
    /**
     * 2 years.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TWO_YEARS,
    /**
     * 5 years.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FIVE_YEARS,
    /**
     * 10 years.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TEN_YEARS,
    /**
     * Retain logs forever.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    INFINITE,
}

==> logs-1.153.1-sources.jar: software/amazon/awscdk/services/logs/RetentionDays.java <==
package software.amazon.awscdk.services.logs;

/**
 * How long, in days, the log contents will be retained.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.logs.*;
 * Role myLogsPublishingRole;
 * Vpc vpc;
 * // Exporting logs from a cluster
 * DatabaseCluster cluster = DatabaseCluster.Builder.create(this, "Database")
 *         .engine(DatabaseClusterEngine.aurora(AuroraClusterEngineProps.builder()
 *                 .version(AuroraEngineVersion.VER_1_17_9)
 *                 .build()))
 *         .instanceProps(InstanceProps.builder()
 *                 .vpc(vpc)
 *                 .build())
 *         .cloudwatchLogsExports(List.of("error", "general", "slowquery", "audit")) // Export all available MySQL-based logs
 *         .cloudwatchLogsRetention(RetentionDays.THREE_MONTHS) // Optional - default is to never expire logs
 *         .cloudwatchLogsRetentionRole(myLogsPublishingRole)
 *         .build();
 * // Exporting logs from an instance
 * DatabaseInstance instance = DatabaseInstance.Builder.create(this, "Instance")
 *         .engine(DatabaseInstanceEngine.postgres(PostgresInstanceEngineProps.builder()
 *                 .version(PostgresEngineVersion.VER_12_3)
 *                 .build()))
 *         .vpc(vpc)
 *         .cloudwatchLogsExports(List.of("postgresql"))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.57.0 (build f614666)", date = "2022-04-23T01:54:29.561Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.logs.$Module.class, fqn = "@aws-cdk/aws-logs.RetentionDays")
public enum RetentionDays {
    /**
     * 1 day.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    ONE_DAY,
    /**
     * 3 days.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    THREE_DAYS,
    /**
     * 5 days.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FIVE_DAYS,
    /**
     * 1 week.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    ONE_WEEK,
    /**
     * 2 weeks.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TWO_WEEKS,
    /**
     * 1 month.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    ONE_MONTH,
    /**
     * 2 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TWO_MONTHS,
    /**
     * 3 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    THREE_MONTHS,
    /**
     * 4 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FOUR_MONTHS,
    /**
     * 5 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FIVE_MONTHS,
    /**
     * 6 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    SIX_MONTHS,
    /**
     * 1 year.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    ONE_YEAR,
    /**
     * 13 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    THIRTEEN_MONTHS,
    /**
     * 18 months.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    EIGHTEEN_MONTHS,
    /**
     * 2 years.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TWO_YEARS,
    /**
     * 5 years.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FIVE_YEARS,
    /**
     * 10 years.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TEN_YEARS,
    /**
     * Retain logs forever.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    INFINITE,
}
